.. _states_module:

:mod:`kazoo.protocol.states`
----------------------------

.. automodule:: kazoo.protocol.states

Public API
++++++++++

    .. autoclass:: EventType

    .. autoclass:: KazooState

    .. autoclass:: KeeperState

    .. autoclass:: WatchedEvent

    .. autoclass:: ZnodeStat

Private API
+++++++++++

    .. autoclass:: Callback
